from sandlerprops.properties import Properties as P
import unittest
import os
import shutil

class Test_db(unittest.TestCase):
   def test_read(self):
      expected_columns=['Formula', 'Name', 'Molwt', 'Tfp', 'Tb', 'Tc', 'Pc',
         'Vc', 'Zc', 'Omega', 'Dipm', 'CpA', 'CpB', 'CpC', 'CpD', 'dHf', 'dGf',
         'Eq', 'VpA', 'VpB', 'VpC', 'VpD', 'Tmin', 'Tmax', 'Lden', 'Tden']
      self.assertTrue(all([x==y for x,y in zip(P.properties,expected_columns)]))
   def test_get_compound(self):
      methane=P.get_compound('methane')
      self.assertEqual(methane.Formula,'CH4')
      no_cmp=P.get_compound('fake-compound')
      self.assertEqual(no_cmp,None)
    


#Author: Cameron F. Abrams, <cfa22@drexel.edu>

import pytest
import os
import logging

logging.getLogger("ycleptic").setLevel(logging.WARNING)
logging.getLogger("numexpr").setLevel(logging.WARNING)
logging.getLogger("matplotlib").setLevel(logging.WARNING)

@pytest.fixture(autouse=True)
def change_test_dir(request, monkeypatch):
    """Causes each test to run in the directory in which the module is found **or** a subdirectory with the same base name as the module

    For example, say you have <packagename>/tests/unit/test_foo.py.  If the directory
    <packagename>/tests/unit/test_foo/ exists, the test will run in that directory; if not, it will run in <packagename>/tests/unit/

    :param request: pytest request
    :type request: pytest request
    :param monkeypatch: pytest monkeypatch
    :type monkeypatch: pytest.Monkeypatch
    """
    module_bn=request.fspath.basename
    module_name,_=os.path.splitext(module_bn)
    print('module name',module_name)
    test_dir=request.fspath.dirname
    subdir=os.path.join(test_dir,module_name)
    if os.path.isdir(subdir):
        monkeypatch.chdir(subdir)
    else:
        monkeypatch.chdir(test_dir)

def pytest_addoption(parser):
    parser.addoption(
        "--runslow", action="store_true", default=False, help="run slow tests"
    )


def pytest_configure(config):
    config.addinivalue_line("markers", "slow: mark test as slow to run")


def pytest_collection_modifyitems(config, items):
    if config.getoption("--runslow"):
        # --runslow given in cli: do not skip slow tests
        return
    skip_slow = pytest.mark.skip(reason="need --runslow option to run")
    for item in items:
        if "slow" in item.keywords:
            item.add_marker(skip_slow)


# Author: Cameron F. Abrams <cfa22@drexel.edu>

import pandas as pd
import os
from argparse import Namespace
from . import resources

datafile_path=os.path.join(os.path.split(resources.__file__)[0],'data','properties_database.csv')


class PropertiesDatabase:
    def __init__(self):
        D=pd.read_csv(datafile_path,header=0,index_col=0)
        self.D=D.rename(columns={'Tfp (K)':'Tfp','Tb (K)':'Tb','Tc (K)':'Tc','Pc (bar)':'Pc'})
        unitlist=['','','g/mol','K','K','K','bar','m3/mol','','','','J/mol-K','J/mol-K2','J/mol-K3','J/mol-K4','J/mol','J/mol','','','','','','K','K','','']
        self.properties=list(self.D.columns)
        unitdict={k:v for k,v in zip(self.properties,unitlist)}
        self.U=Namespace(**unitdict)

    def get_compound(self,name):
        row=self.D[self.D['Name']==name]
        if not row.empty:
            d=row.to_dict('records')[0]
            return Namespace(**d)
        return None
        
Properties=PropertiesDatabase()
